@@ -1,5 +1,3 @@
-from terra_sdk.core import Coin, Dec
-
 from ._base import BaseAsyncAPI, sync_bind
 
 __all__ = ["AsyncIbcAPI", "IbcAPI"]
@@ -13,8 +11,7 @@ class AsyncIbcAPI(BaseAsyncAPI):
             List: allowed clients
         """
         res = await self._c._get("/ibc/client/v1/params")
-        params = res["params"]
-        return params["allowed_clients"]
+        return res["params"]
 
     # TODO: functions for clients, connections and channels
 
