@@ -1,11 +1,9 @@
 import base64
 import copy
-import urllib.parse
-from typing import List, Optional, Union, Dict
-from multidict import CIMultiDict
-import attr
+from typing import List, Optional
 
-from ..params import APIParams
+import attr
+from multidict import CIMultiDict
 
 from terra_sdk.core import AccAddress, Coins, Dec, Numeric, PublicKey
 from terra_sdk.core.broadcast import (
@@ -14,25 +12,31 @@ from terra_sdk.core.broadcast import (
     SyncTxBroadcastResult,
 )
 from terra_sdk.core.msg import Msg
-from terra_sdk.core.block import Block
 from terra_sdk.core.tx import AuthInfo, Fee, SignerData, SignMode, Tx, TxBody, TxInfo
 from terra_sdk.util.hash import hash_amino
 from terra_sdk.util.json import JSONSerializable
-from . import tendermint
 
+from ..params import APIParams
 from ._base import BaseAsyncAPI, sync_bind
 
-__all__ = ["AsyncTxAPI", "TxAPI", "BroadcastOptions", "CreateTxOptions"]
+__all__ = [
+    "AsyncTxAPI",
+    "TxAPI",
+    "BroadcastOptions",
+    "CreateTxOptions",
+    "SignerOptions",
+]
 
 
 @attr.s
 class SignerOptions:
-    """ SignerOptions specifies infomations about signers
-        Args:
-            address (AccAddress): address of the signer
-            sequence (int, optional): nonce of the messages from the signer
-            public_key (PublicKey, optional): signer's PublicKey
+    """SignerOptions specifies infomations about signers
+    Args:
+        address (AccAddress): address of the signer
+        sequence (int, optional): nonce of the messages from the signer
+        public_key (PublicKey, optional): signer's PublicKey
     """
+
     address: AccAddress = attr.ib()
     sequence: Optional[int] = attr.ib(default=None)
     public_key: Optional[PublicKey] = attr.ib(default=None)
@@ -47,6 +51,7 @@ class CreateTxOptions:
         fee (Optional[Fee], optional): transaction fee. If ``None``, will be estimated.
             See more on `fee estimation`_.
         memo (str, optional): optional short string to include with transaction.
+        gas (str, optional): gas limit to set per-transaction; set to "auto" to calculate sufficient gas automatically
         gas_prices (Coins.Input, optional): gas prices for fee estimation.
         gas_adjustment (Numeric.Input, optional): gas adjustment for fee estimation.
         fee_denoms (List[str], optional): list of denoms to use for fee after estimation.
@@ -56,13 +61,14 @@ class CreateTxOptions:
         timeout_height (int, optional):  specifies a block timeout height to prevent the tx from being committed past a certain height.
         sign_mode: (SignMode, optional): SignMode.SIGN_MODE_DIRECT by default. multisig needs SignMode.SIGN_MODE_LEGACY_AMINO_JSON.
     """
+
     msgs: List[Msg] = attr.ib()
     fee: Optional[Fee] = attr.ib(default=None)
     memo: Optional[str] = attr.ib(default=None)
     gas: Optional[str] = attr.ib(default=None)
     gas_prices: Optional[Coins.Input] = attr.ib(default=None)
     gas_adjustment: Optional[Numeric.Output] = attr.ib(
-        default=1, converter=Numeric.parse
+        default=0, converter=Numeric.parse
     )
     fee_denoms: Optional[List[str]] = attr.ib(default=None)
     account_number: Optional[int] = attr.ib(default=None)
@@ -140,15 +146,8 @@ class AsyncTxAPI(BaseAsyncAPI):
         chain ID, account number, sequence and fee estimation.
 
         Args:
-            sender (AccAddress): transaction sender's account address
-            msgs (List[Msg]): list of messages to include
-            fee (Optional[Fee], optional): fee to use (estimates if empty).
-            memo (str, optional): memo to use. Defaults to "".
-            gas_prices (Optional[Coins.Input], optional): gas prices for fee estimation.
-            gas_adjustment (Optional[Numeric.Input], optional): gas adjustment for fee estimation.
-            fee_denoms (Optional[List[str]], optional): list of denoms to use for gas fee when estimating.
-            account_number (Optional[int], optional): account number to use.
-            sequence (Optional[int], optional): sequence number to use.
+            signers (List[SingerOptions]): options about signers
+            options (CreateTxOptions): options about creating a tx
 
         Returns:
             Tx: unsigned tx
@@ -201,7 +200,7 @@ class AsyncTxAPI(BaseAsyncAPI):
         if gas_prices:
             gas_prices_coins = Coins(gas_prices)
             if options.fee_denoms:
-                _fee_denoms = options.fee_denoms if options.fee_denoms else ['uusd']
+                _fee_denoms = options.fee_denoms if options.fee_denoms else ["uusd"]
                 gas_prices_coins = gas_prices_coins.filter(
                     lambda c: c.denom in _fee_denoms
                 )
@@ -214,12 +213,16 @@ class AsyncTxAPI(BaseAsyncAPI):
         tx.append_empty_signatures(signers)
 
         gas = options.gas
-        if gas is None or gas == "auto" or gas == 0:
+        if gas is None or gas == "auto" or int(gas) == 0:
             opt = copy.deepcopy(options)
             opt.gas_adjustment = gas_adjustment
-            gas = str(self.estimate_gas(tx, opt))
+            gas = str(await super()._try_await(self.estimate_gas(tx, opt)))
 
-        fee_amount = gas_prices_coins.mul(gas).to_int_coins() if gas_prices_coins else Coins.from_str('0uusd')
+        fee_amount = (
+            gas_prices_coins.mul(gas).to_int_ceil_coins()
+            if gas_prices_coins
+            else Coins.from_str("0uusd")
+        )
 
         return Fee(Numeric.parse(gas), fee_amount, "", "")
 
@@ -227,7 +230,8 @@ class AsyncTxAPI(BaseAsyncAPI):
         gas_adjustment = options.gas_adjustment if options else self._c.gas_adjustment
 
         res = await self._c._post(
-            "/cosmos/tx/v1beta1/simulate", {"tx_bytes": self.encode(tx)}
+            "/cosmos/tx/v1beta1/simulate",
+            {"tx_bytes": await super()._try_await(self.encode(tx))},
         )
         simulated = SimulateResponse.from_data(res)
 
@@ -256,7 +260,7 @@ class AsyncTxAPI(BaseAsyncAPI):
     async def _broadcast(
         self, tx: Tx, mode: str, options: BroadcastOptions = None
     ) -> dict:
-        data = {"tx_bytes": self.encode(tx), "mode": mode}
+        data = {"tx_bytes": await super()._try_await(self.encode(tx)), "mode": mode}
         return await self._c._post("/cosmos/tx/v1beta1/txs", data)  # , raw=True)
 
     async def broadcast_sync(
@@ -321,7 +325,9 @@ class AsyncTxAPI(BaseAsyncAPI):
             codespace=res.get("codespace"),
         )
 
-    async def search(self, events: List[list], params: Optional[APIParams] = None) -> dict:
+    async def search(
+        self, events: List[list], params: Optional[APIParams] = None
+    ) -> dict:
         """Searches for transactions given criteria.
 
         Args:
@@ -346,7 +352,7 @@ class AsyncTxAPI(BaseAsyncAPI):
         res = await self._c._get("/cosmos/tx/v1beta1/txs", actual_params)
         return {
             "txs": [TxInfo.from_data(tx) for tx in res.get("tx_responses")],
-            "pagination": res.get("pagination")
+            "pagination": res.get("pagination"),
         }
 
     async def tx_infos_by_height(self, height: Optional[int] = None) -> List[TxInfo]:
