@@ -8,7 +8,7 @@ from .api._base import BaseAsyncAPI, sync_bind
 
 
 def index_by_pub_key(m: Dict[str, Any], o: Any):
-    m[o["pub_key"]] = o
+    m[o["pub_key"]["key"]] = o
     return m
 
 
@@ -36,13 +36,22 @@ class AsyncLCDUtils(BaseAsyncAPI):
         validator_set_response = await BaseAsyncAPI._try_await(
             self._c.tendermint.validator_set()
         )
-        validators = await BaseAsyncAPI._try_await(self._c.staking.validators())
-        validator_set: Dict[str, Any] = reduce(
-            index_by_pub_key, validator_set_response["validators"], {}
-        )
+        next_key = ""
+        while True:
+            from terra_sdk.client.lcd import PaginationOptions
+
+            validators, pag = await BaseAsyncAPI._try_await(
+                self._c.staking.validators(PaginationOptions(key=next_key))
+            )
+            validator_set: Dict[str, Any] = reduce(
+                index_by_pub_key, validator_set_response["validators"], {}
+            )
+            if pag is None or pag["next_key"] is None:
+                break
+            next_key = pag["next_key"]
         res = {}
         for v in validators:
-            delegate_info = validator_set[v.consensus_pubkey]
+            delegate_info = validator_set.get(v.consensus_pubkey["key"])
             if delegate_info is None:
                 continue
             res[v.operator_address] = {
