@@ -7,8 +7,7 @@ from .base_account import BaseAccount
 from .lazy_graded_vesting_account import LazyGradedVestingAccount
 
 
-class Account(JSONSerializable):
-
+class Account(JSONSerializable, ABC):
     @abstractmethod
     def get_account_number(self) -> int:
         pass
@@ -21,6 +20,13 @@ class Account(JSONSerializable):
     def get_public_key(self) -> PublicKey:
         pass
 
+    @classmethod
+    def from_amino(cls, amino: dict):  # -> Account:
+        if amino["type"] == BaseAccount.type_amino:
+            return BaseAccount.from_amino(amino)
+        else:
+            return LazyGradedVestingAccount.from_amino(amino)
+
     @classmethod
     def from_data(cls, data: dict):  # -> Account:
         if data["@type"] == BaseAccount.type_url:
