@@ -2,12 +2,12 @@
 
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import Optional
 
 import attr
 from terra_proto.cosmos.auth.v1beta1 import BaseAccount as BaseAccount_pb
 
-from ....core import AccAddress, Coins
+from ....core import AccAddress
 from ....util.json import JSONSerializable
 from ...public_key import PublicKey
 
@@ -39,11 +39,21 @@ class BaseAccount(JSONSerializable):
             "value": {
                 "address": self.address,
                 "public_key": self.public_key.to_amino(),
-                "account_number": self.account_number,
-                "sequence": self.sequence
-            }
+                "account_number": str(self.account_number),
+                "sequence": str(self.sequence),
+            },
         }
 
+    @classmethod
+    def from_amino(cls, amino: dict) -> BaseAccount:
+        amino = amino["value"]
+        return cls(
+            address=amino["address"],
+            public_key=PublicKey.from_amino(amino["public_key"]),
+            account_number=amino["account_number"],
+            sequence=amino["sequence"],
+        )
+
     def get_account_number(self) -> int:
         return self.account_number
 
@@ -57,7 +67,7 @@ class BaseAccount(JSONSerializable):
         return {
             "@type": self.type_url,
             "address": self.address,
-            "public_key": self.public_key and self.public_key.to_data(),
+            "pub_key": self.public_key and self.public_key.to_data(),
             "account_number": str(self.account_number),
             "sequence": str(self.sequence),
         }
@@ -66,8 +76,7 @@ class BaseAccount(JSONSerializable):
     def from_data(cls, data: dict) -> BaseAccount:
         return cls(
             address=data["address"],
-            public_key=data.get("public_key")
-            and PublicKey.from_data(data["public_key"]),
+            public_key=data.get("pub_key") and PublicKey.from_data(data["pub_key"]),
             account_number=data.get("account_number") or 0,
             sequence=data.get("sequence") or 0,
         )
