@@ -3,10 +3,10 @@
 from __future__ import annotations
 
 import base64
-import attr
-
+import json
 from typing import Dict, List, Optional
 
+import attr
 from terra_proto.cosmos.base.abci.v1beta1 import AbciMessageLog as AbciMessageLog_pb
 from terra_proto.cosmos.base.abci.v1beta1 import Attribute as Attribute_pb
 from terra_proto.cosmos.base.abci.v1beta1 import StringEvent as StringEvent_pb
@@ -17,13 +17,17 @@ from terra_proto.cosmos.tx.v1beta1 import SignerInfo as SignerInfo_pb
 from terra_proto.cosmos.tx.v1beta1 import Tx as Tx_pb
 from terra_proto.cosmos.tx.v1beta1 import TxBody as TxBody_pb
 
-from terra_sdk.core.signature_v2 import SignatureV2
 from terra_sdk.core.compact_bit_array import CompactBitArray
 from terra_sdk.core.fee import Fee
+from terra_sdk.core.mode_info import ModeInfo, ModeInfoMulti, ModeInfoSingle
 from terra_sdk.core.msg import Msg
-from terra_sdk.core.public_key import LegacyAminoMultisigPublicKey, PublicKey, SimplePublicKey
+from terra_sdk.core.public_key import (
+    LegacyAminoMultisigPublicKey,
+    PublicKey,
+    SimplePublicKey,
+)
+from terra_sdk.core.signature_v2 import SignatureV2
 from terra_sdk.util.json import JSONSerializable
-from terra_sdk.core.mode_info import ModeInfo, ModeInfoSingle, ModeInfoMulti
 
 __all__ = [
     "SignMode",
@@ -109,7 +113,8 @@ class Tx(JSONSerializable):
                             multi=ModeInfoMulti(
                                 CompactBitArray.from_bits(
                                     len(signer.public_key.public_keys)
-                                )
+                                ),
+                                [],
                             )
                         ),
                     )
@@ -137,7 +142,8 @@ class Tx(JSONSerializable):
     def append_signatures(self, signatures: List[SignatureV2]):
         for sig in signatures:
             mode_info, sig_bytes = sig.data.to_mode_info_and_signature()
-            self.signatures.append(base64.b64decode(sig_bytes))
+            self.signatures.append(sig_bytes)
+            # self.signatures.append(base64.b64decode(sig_bytes))
             self.auth_info.signer_infos.append(
                 SignerInfo(sig.public_key, mode_info, sig.sequence)
             )
@@ -161,7 +167,7 @@ class TxBody(JSONSerializable):
         return {
             "messages": [m.to_data() for m in self.messages],
             "memo": self.memo if self.memo else "",
-            "timeout_height": self.timeout_height if self.timeout_height else 0,
+            "timeout_height": self.timeout_height if self.timeout_height else "0",
         }
 
     def to_proto(self) -> TxBody_pb:
@@ -318,6 +324,14 @@ class TxLog(JSONSerializable):
         events = [event for event in tx_log["events"]]
         return cls(msg_index=tx_log["msg_index"], log=tx_log["log"], events=events)
 
+    def to_proto(self) -> AbciMessageLog_pb:
+        str_events = List
+        for event in self.events:
+            str_events.append(json.dumps(event))
+        return AbciMessageLog_pb(
+            msg_index=self.msg_index, log=self.log, events=str_events
+        )
+
 
 @attr.s
 class Attribute(JSONSerializable):
@@ -438,7 +452,7 @@ class TxInfo(JSONSerializable):
             parse_tx_logs(data.get("logs")),
             data["gas_wanted"],
             data["gas_used"],
-            Tx.from_data(data['tx']),
+            Tx.from_data(data["tx"]),
             data["timestamp"],
             data.get("code"),
             data.get("codespace"),
