@@ -1,6 +1,6 @@
 import copy
 import json
-from abc import ABC, abstractmethod
+from abc import ABC
 from datetime import datetime
 from typing import Any
 
